@@ -102,8 +102,7 @@ class DiffusionField(Process):
     def ports_schema(self):
         local_concentration_schema = {
             molecule: {
-                '_default': 0.0,
-                '_updater': 'set'}
+                '_default': 0.0}
             for molecule in self.molecule_ids}
 
         # agents glob schema
@@ -180,7 +179,9 @@ class DiffusionField(Process):
         bin_site = self.get_bin_site(specs['location'])
         local_environment = {}
         for mol_id, field in fields.items():
-            local_environment[mol_id] = field[bin_site]
+            local_environment[mol_id] = {
+                '_value': field[bin_site],
+                '_updater': 'set'}
         return local_environment
 
     def get_local_environments(self, agents, fields):
